You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@directory.apache.org by el...@apache.org on 2007/04/15 21:08:15 UTC

svn commit: r529046 [3/5] - in /directory/apacheds/trunk/core/src: main/java/org/apache/directory/server/core/ main/java/org/apache/directory/server/core/authn/ main/java/org/apache/directory/server/core/authz/ main/java/org/apache/directory/server/cor...

Copied: directory/apacheds/trunk/core/src/main/java/org/apache/directory/server/core/interceptor/context/GetRootDSEOperationContext.java (from r528981, directory/apacheds/trunk/core/src/main/java/org/apache/directory/server/core/interceptor/context/GetRootDSEServiceContext.java)
URL: http://svn.apache.org/viewvc/directory/apacheds/trunk/core/src/main/java/org/apache/directory/server/core/interceptor/context/GetRootDSEOperationContext.java?view=diff&rev=529046&p1=directory/apacheds/trunk/core/src/main/java/org/apache/directory/server/core/interceptor/context/GetRootDSEServiceContext.java&r1=528981&p2=directory/apacheds/trunk/core/src/main/java/org/apache/directory/server/core/interceptor/context/GetRootDSEOperationContext.java&r2=529046
==============================================================================
--- directory/apacheds/trunk/core/src/main/java/org/apache/directory/server/core/interceptor/context/GetRootDSEServiceContext.java (original)
+++ directory/apacheds/trunk/core/src/main/java/org/apache/directory/server/core/interceptor/context/GetRootDSEOperationContext.java Sun Apr 15 12:08:12 2007
@@ -28,22 +28,22 @@
  * @author <a href="mailto:dev@directory.apache.org">Apache Directory Project</a>
  * @version $Rev$, $Date$
  */
-public class GetRootDSEServiceContext  extends AbstractServiceContext
+public class GetRootDSEOperationContext  extends AbstractOperationContext
 {
     /**
-     * Creates a new instance of GetRootDSEServiceContext.
+     * Creates a new instance of GetRootDSEOperationContext.
      */
-    public GetRootDSEServiceContext()
+    public GetRootDSEOperationContext()
     {
         super();
     }
     
     /**
-     * Creates a new instance of GetRootDSEServiceContext.
+     * Creates a new instance of GetRootDSEOperationContext.
      *
      * @param dn The entry DN used to get the rootDSE
      */
-    public GetRootDSEServiceContext( LdapDN dn )
+    public GetRootDSEOperationContext( LdapDN dn )
     {
         super( dn );
     }

Copied: directory/apacheds/trunk/core/src/main/java/org/apache/directory/server/core/interceptor/context/GetSuffixOperationContext.java (from r528981, directory/apacheds/trunk/core/src/main/java/org/apache/directory/server/core/interceptor/context/GetSuffixServiceContext.java)
URL: http://svn.apache.org/viewvc/directory/apacheds/trunk/core/src/main/java/org/apache/directory/server/core/interceptor/context/GetSuffixOperationContext.java?view=diff&rev=529046&p1=directory/apacheds/trunk/core/src/main/java/org/apache/directory/server/core/interceptor/context/GetSuffixServiceContext.java&r1=528981&p2=directory/apacheds/trunk/core/src/main/java/org/apache/directory/server/core/interceptor/context/GetSuffixOperationContext.java&r2=529046
==============================================================================
--- directory/apacheds/trunk/core/src/main/java/org/apache/directory/server/core/interceptor/context/ListOperationContext.java (added)
+++ directory/apacheds/trunk/core/src/main/java/org/apache/directory/server/core/interceptor/context/ListOperationContext.java Sun Apr 15 12:08:12 2007
@@ -0,0 +1,58 @@
+/*
+ *  Licensed to the Apache Software Foundation (ASF) under one
+ *  or more contributor license agreements.  See the NOTICE file
+ *  distributed with this work for additional information
+ *  regarding copyright ownership.  The ASF licenses this file
+ *  to you under the Apache License, Version 2.0 (the
+ *  "License"); you may not use this file except in compliance
+ *  with the License.  You may obtain a copy of the License at
+ *  
+ *    http://www.apache.org/licenses/LICENSE-2.0
+ *  
+ *  Unless required by applicable law or agreed to in writing,
+ *  software distributed under the License is distributed on an
+ *  "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
+ *  KIND, either express or implied.  See the License for the
+ *  specific language governing permissions and limitations
+ *  under the License. 
+ *  
+ */
+package org.apache.directory.server.core.interceptor.context;
+
+import org.apache.directory.shared.ldap.name.LdapDN;
+
+/**
+ * A ListContext context used for Interceptors. It contains all the informations
+ * needed for the List operation, and used by all the interceptors
+ *
+ * @author <a href="mailto:dev@directory.apache.org">Apache Directory Project</a>
+ * @version $Rev$, $Date$
+ */
+public class ListOperationContext  extends AbstractOperationContext
+{
+    /**
+     * Creates a new instance of ListOperationContext.
+     */
+    public ListOperationContext()
+    {
+        super();
+    }
+    
+    /**
+     * Creates a new instance of ListOperationContext.
+     *
+     * @param dn The DN to get the suffix from
+     */
+    public ListOperationContext( LdapDN dn )
+    {
+        super( dn );
+    }
+    
+    /**
+     * @see Object#toString()
+     */
+    public String toString()
+    {
+        return "ListOperationContext with DN '" + getDn().getUpName() + "'";
+    }
+}

Copied: directory/apacheds/trunk/core/src/main/java/org/apache/directory/server/core/interceptor/context/LookupOperationContext.java (from r528981, directory/apacheds/trunk/core/src/main/java/org/apache/directory/server/core/interceptor/context/LookupServiceContext.java)
URL: http://svn.apache.org/viewvc/directory/apacheds/trunk/core/src/main/java/org/apache/directory/server/core/interceptor/context/LookupOperationContext.java?view=diff&rev=529046&p1=directory/apacheds/trunk/core/src/main/java/org/apache/directory/server/core/interceptor/context/LookupServiceContext.java&r1=528981&p2=directory/apacheds/trunk/core/src/main/java/org/apache/directory/server/core/interceptor/context/LookupOperationContext.java&r2=529046
==============================================================================
--- directory/apacheds/trunk/core/src/main/java/org/apache/directory/server/core/interceptor/context/LookupServiceContext.java (original)
+++ directory/apacheds/trunk/core/src/main/java/org/apache/directory/server/core/interceptor/context/LookupOperationContext.java Sun Apr 15 12:08:12 2007
@@ -33,7 +33,7 @@
  * @author <a href="mailto:dev@directory.apache.org">Apache Directory Project</a>
  * @version $Rev$, $Date$
  */
-public class LookupServiceContext  extends AbstractServiceContext
+public class LookupOperationContext  extends AbstractOperationContext
 {
     /** The list of attributes id to return */
     private List<String> attrsId;
@@ -43,30 +43,30 @@
     
     /**
      * 
-     * Creates a new instance of LookupServiceContext.
+     * Creates a new instance of LookupOperationContext.
      *
      */
-    public LookupServiceContext()
+    public LookupOperationContext()
     {
     	super();
     }
 
     /**
      * 
-     * Creates a new instance of LookupServiceContext.
+     * Creates a new instance of LookupOperationContext.
      *
      */
-    public LookupServiceContext( LdapDN dn )
+    public LookupOperationContext( LdapDN dn )
     {
         super( dn );
     }
 
     /**
      * 
-     * Creates a new instance of LookupServiceContext.
+     * Creates a new instance of LookupOperationContext.
      *
      */
-    public LookupServiceContext( String attrsId[] )
+    public LookupOperationContext( String attrsId[] )
     {
     	super();
         this.attrsId = new ArrayList<String>();
@@ -76,10 +76,10 @@
 
     /**
      * 
-     * Creates a new instance of LookupServiceContext.
+     * Creates a new instance of LookupOperationContext.
      *
      */
-    public LookupServiceContext( LdapDN dn, String attrsId[] )
+    public LookupOperationContext( LdapDN dn, String attrsId[] )
     {
         super( dn );
         this.attrsId = new ArrayList<String>();

Copied: directory/apacheds/trunk/core/src/main/java/org/apache/directory/server/core/interceptor/context/ModifyOperationContext.java (from r528981, directory/apacheds/trunk/core/src/main/java/org/apache/directory/server/core/interceptor/context/ModifyServiceContext.java)
URL: http://svn.apache.org/viewvc/directory/apacheds/trunk/core/src/main/java/org/apache/directory/server/core/interceptor/context/ModifyOperationContext.java?view=diff&rev=529046&p1=directory/apacheds/trunk/core/src/main/java/org/apache/directory/server/core/interceptor/context/ModifyServiceContext.java&r1=528981&p2=directory/apacheds/trunk/core/src/main/java/org/apache/directory/server/core/interceptor/context/ModifyOperationContext.java&r2=529046
==============================================================================
--- directory/apacheds/trunk/core/src/main/java/org/apache/directory/server/core/interceptor/context/ModifyServiceContext.java (original)
+++ directory/apacheds/trunk/core/src/main/java/org/apache/directory/server/core/interceptor/context/ModifyOperationContext.java Sun Apr 15 12:08:12 2007
@@ -30,7 +30,7 @@
  * @author <a href="mailto:dev@directory.apache.org">Apache Directory Project</a>
  * @version $Rev$, $Date$
  */
-public class ModifyServiceContext extends AbstractServiceContext
+public class ModifyOperationContext extends AbstractOperationContext
 {
     /** The modification type */
     private int modOp;
@@ -40,30 +40,30 @@
     
     /**
      * 
-     * Creates a new instance of ModifyServiceContext.
+     * Creates a new instance of ModifyOperationContext.
      *
      */
-    public ModifyServiceContext()
+    public ModifyOperationContext()
     {
     	super();
     }
 
     /**
      * 
-     * Creates a new instance of ModifyServiceContext.
+     * Creates a new instance of ModifyOperationContext.
      *
      */
-    public ModifyServiceContext( LdapDN dn )
+    public ModifyOperationContext( LdapDN dn )
     {
         super( dn );
     }
 
     /**
      * 
-     * Creates a new instance of ModifyServiceContext.
+     * Creates a new instance of ModifyOperationContext.
      *
      */
-    public ModifyServiceContext( LdapDN dn, int modOp, Attributes mods )
+    public ModifyOperationContext( LdapDN dn, int modOp, Attributes mods )
     {
     	super( dn );
         this.modOp = modOp;

Copied: directory/apacheds/trunk/core/src/main/java/org/apache/directory/server/core/interceptor/context/MoveAndRenameOperationContext.java (from r528981, directory/apacheds/trunk/core/src/main/java/org/apache/directory/server/core/interceptor/context/MoveAndRenameServiceContext.java)
URL: http://svn.apache.org/viewvc/directory/apacheds/trunk/core/src/main/java/org/apache/directory/server/core/interceptor/context/MoveAndRenameOperationContext.java?view=diff&rev=529046&p1=directory/apacheds/trunk/core/src/main/java/org/apache/directory/server/core/interceptor/context/MoveAndRenameServiceContext.java&r1=528981&p2=directory/apacheds/trunk/core/src/main/java/org/apache/directory/server/core/interceptor/context/MoveAndRenameOperationContext.java&r2=529046
==============================================================================
--- directory/apacheds/trunk/core/src/main/java/org/apache/directory/server/core/interceptor/context/MoveAndRenameServiceContext.java (original)
+++ directory/apacheds/trunk/core/src/main/java/org/apache/directory/server/core/interceptor/context/MoveAndRenameOperationContext.java Sun Apr 15 12:08:12 2007
@@ -28,27 +28,27 @@
  * @author <a href="mailto:dev@directory.apache.org">Apache Directory Project</a>
  * @version $Rev$, $Date$
  */
-public class MoveAndRenameServiceContext extends RenameServiceContext
+public class MoveAndRenameOperationContext extends RenameOperationContext
 {
     /** The parent DN */
     private LdapDN parent;
     
     /**
      * 
-     * Creates a new instance of MoveAndRenameServiceContext.
+     * Creates a new instance of MoveAndRenameOperationContext.
      *
      */
-    public MoveAndRenameServiceContext()
+    public MoveAndRenameOperationContext()
     {
     	super();
     }
 
     /**
      * 
-     * Creates a new instance of MoveAndRenameServiceContext.
+     * Creates a new instance of MoveAndRenameOperationContext.
      *
      */
-    public MoveAndRenameServiceContext( LdapDN oldDn, LdapDN parent, String newRdn, boolean delOldDn )
+    public MoveAndRenameOperationContext( LdapDN oldDn, LdapDN parent, String newRdn, boolean delOldDn )
     {
         super( oldDn, newRdn, delOldDn );
         this.parent = parent;

Copied: directory/apacheds/trunk/core/src/main/java/org/apache/directory/server/core/interceptor/context/MoveOperationContext.java (from r528981, directory/apacheds/trunk/core/src/main/java/org/apache/directory/server/core/interceptor/context/MoveServiceContext.java)
URL: http://svn.apache.org/viewvc/directory/apacheds/trunk/core/src/main/java/org/apache/directory/server/core/interceptor/context/MoveOperationContext.java?view=diff&rev=529046&p1=directory/apacheds/trunk/core/src/main/java/org/apache/directory/server/core/interceptor/context/MoveServiceContext.java&r1=528981&p2=directory/apacheds/trunk/core/src/main/java/org/apache/directory/server/core/interceptor/context/MoveOperationContext.java&r2=529046
==============================================================================
--- directory/apacheds/trunk/core/src/main/java/org/apache/directory/server/core/interceptor/context/MoveServiceContext.java (original)
+++ directory/apacheds/trunk/core/src/main/java/org/apache/directory/server/core/interceptor/context/MoveOperationContext.java Sun Apr 15 12:08:12 2007
@@ -28,27 +28,27 @@
  * @author <a href="mailto:dev@directory.apache.org">Apache Directory Project</a>
  * @version $Rev$, $Date$
  */
-public class MoveServiceContext extends AbstractServiceContext
+public class MoveOperationContext extends AbstractOperationContext
 {
     /** The parent DN */
     private LdapDN parent;
     
     /**
      * 
-     * Creates a new instance of MoveServiceContext.
+     * Creates a new instance of MoveOperationContext.
      *
      */
-    public MoveServiceContext()
+    public MoveOperationContext()
     {
     	super();
     }
 
     /**
      * 
-     * Creates a new instance of MoveServiceContext.
+     * Creates a new instance of MoveOperationContext.
      *
      */
-    public MoveServiceContext( LdapDN oldDn, LdapDN parent )
+    public MoveOperationContext( LdapDN oldDn, LdapDN parent )
     {
         super( oldDn );
         this.parent = parent;

Copied: directory/apacheds/trunk/core/src/main/java/org/apache/directory/server/core/interceptor/context/OperationContext.java (from r528981, directory/apacheds/trunk/core/src/main/java/org/apache/directory/server/core/interceptor/context/ServiceContext.java)
URL: http://svn.apache.org/viewvc/directory/apacheds/trunk/core/src/main/java/org/apache/directory/server/core/interceptor/context/OperationContext.java?view=diff&rev=529046&p1=directory/apacheds/trunk/core/src/main/java/org/apache/directory/server/core/interceptor/context/ServiceContext.java&r1=528981&p2=directory/apacheds/trunk/core/src/main/java/org/apache/directory/server/core/interceptor/context/OperationContext.java&r2=529046
==============================================================================
--- directory/apacheds/trunk/core/src/main/java/org/apache/directory/server/core/interceptor/context/ServiceContext.java (original)
+++ directory/apacheds/trunk/core/src/main/java/org/apache/directory/server/core/interceptor/context/OperationContext.java Sun Apr 15 12:08:12 2007
@@ -28,7 +28,7 @@
  * @author <a href="mailto:dev@directory.apache.org">Apache Directory Project</a>
  * @version $Rev$, $Date$
  */
-public interface ServiceContext
+public interface OperationContext
 {
     /**
      * @return The associated DN

Copied: directory/apacheds/trunk/core/src/main/java/org/apache/directory/server/core/interceptor/context/RemoveContextPartitionOperationContext.java (from r528981, directory/apacheds/trunk/core/src/main/java/org/apache/directory/server/core/interceptor/context/RemoveContextPartitionServiceContext.java)
URL: http://svn.apache.org/viewvc/directory/apacheds/trunk/core/src/main/java/org/apache/directory/server/core/interceptor/context/RemoveContextPartitionOperationContext.java?view=diff&rev=529046&p1=directory/apacheds/trunk/core/src/main/java/org/apache/directory/server/core/interceptor/context/RemoveContextPartitionServiceContext.java&r1=528981&p2=directory/apacheds/trunk/core/src/main/java/org/apache/directory/server/core/interceptor/context/RemoveContextPartitionOperationContext.java&r2=529046
==============================================================================
--- directory/apacheds/trunk/core/src/main/java/org/apache/directory/server/core/interceptor/context/RemoveContextPartitionServiceContext.java (original)
+++ directory/apacheds/trunk/core/src/main/java/org/apache/directory/server/core/interceptor/context/RemoveContextPartitionOperationContext.java Sun Apr 15 12:08:12 2007
@@ -28,21 +28,21 @@
  * @author <a href="mailto:dev@directory.apache.org">Apache Directory Project</a>
  * @version $Rev$, $Date$
  */
-public class RemoveContextPartitionServiceContext  extends AbstractServiceContext
+public class RemoveContextPartitionOperationContext  extends AbstractOperationContext
 {
     /**
-     * Creates a new instance of RemoveContextPartitionServiceContext.
+     * Creates a new instance of RemoveContextPartitionOperationContext.
      */
-    public RemoveContextPartitionServiceContext()
+    public RemoveContextPartitionOperationContext()
     {
     }
     
     /**
-     * Creates a new instance of RemoveContextPartitionServiceContext.
+     * Creates a new instance of RemoveContextPartitionOperationContext.
      *
      * @param entryDn The Entry DN from which the partition should be removed
      */
-    public RemoveContextPartitionServiceContext( LdapDN dn )
+    public RemoveContextPartitionOperationContext( LdapDN dn )
     {
         super( dn );
     }
@@ -52,6 +52,6 @@
      */
     public String toString()
     {
-        return "RemoveContextPartitionServiceContext for DN '" + getDn().getUpName() + "'";
+        return "RemoveContextPartitionOperationContext for DN '" + getDn().getUpName() + "'";
     }
 }

Copied: directory/apacheds/trunk/core/src/main/java/org/apache/directory/server/core/interceptor/context/RenameOperationContext.java (from r528981, directory/apacheds/trunk/core/src/main/java/org/apache/directory/server/core/interceptor/context/RenameServiceContext.java)
URL: http://svn.apache.org/viewvc/directory/apacheds/trunk/core/src/main/java/org/apache/directory/server/core/interceptor/context/RenameOperationContext.java?view=diff&rev=529046&p1=directory/apacheds/trunk/core/src/main/java/org/apache/directory/server/core/interceptor/context/RenameServiceContext.java&r1=528981&p2=directory/apacheds/trunk/core/src/main/java/org/apache/directory/server/core/interceptor/context/RenameOperationContext.java&r2=529046
==============================================================================
--- directory/apacheds/trunk/core/src/main/java/org/apache/directory/server/core/interceptor/context/RenameServiceContext.java (original)
+++ directory/apacheds/trunk/core/src/main/java/org/apache/directory/server/core/interceptor/context/RenameOperationContext.java Sun Apr 15 12:08:12 2007
@@ -30,7 +30,7 @@
  * @author <a href="mailto:dev@directory.apache.org">Apache Directory Project</a>
  * @version $Rev$, $Date$
  */
-public class RenameServiceContext extends AbstractServiceContext
+public class RenameOperationContext extends AbstractOperationContext
 {
     /** The new DN */
     private String newRdn;
@@ -40,20 +40,20 @@
     
     /**
      * 
-     * Creates a new instance of RenameServiceContext.
+     * Creates a new instance of RenameOperationContext.
      *
      */
-    public RenameServiceContext()
+    public RenameOperationContext()
     {
     	super();
     }
 
     /**
      * 
-     * Creates a new instance of RenameServiceContext.
+     * Creates a new instance of RenameOperationContext.
      *
      */
-    public RenameServiceContext( LdapDN oldDn, String newRdn, boolean delOldDn )
+    public RenameOperationContext( LdapDN oldDn, String newRdn, boolean delOldDn )
     {
         super( oldDn );
         this.newRdn = newRdn;

Copied: directory/apacheds/trunk/core/src/main/java/org/apache/directory/server/core/interceptor/context/ReplaceOperationContext.java (from r528981, directory/apacheds/trunk/core/src/main/java/org/apache/directory/server/core/interceptor/context/ReplaceServiceContext.java)
URL: http://svn.apache.org/viewvc/directory/apacheds/trunk/core/src/main/java/org/apache/directory/server/core/interceptor/context/ReplaceOperationContext.java?view=diff&rev=529046&p1=directory/apacheds/trunk/core/src/main/java/org/apache/directory/server/core/interceptor/context/ReplaceServiceContext.java&r1=528981&p2=directory/apacheds/trunk/core/src/main/java/org/apache/directory/server/core/interceptor/context/ReplaceOperationContext.java&r2=529046
==============================================================================
--- directory/apacheds/trunk/core/src/main/java/org/apache/directory/server/core/interceptor/context/ReplaceServiceContext.java (original)
+++ directory/apacheds/trunk/core/src/main/java/org/apache/directory/server/core/interceptor/context/ReplaceOperationContext.java Sun Apr 15 12:08:12 2007
@@ -28,27 +28,27 @@
  * @author <a href="mailto:dev@directory.apache.org">Apache Directory Project</a>
  * @version $Rev$, $Date$
  */
-public class ReplaceServiceContext extends AbstractServiceContext
+public class ReplaceOperationContext extends AbstractOperationContext
 {
     /** The parent DN */
     private LdapDN parent;
     
     /**
      * 
-     * Creates a new instance of ReplaceServiceContext.
+     * Creates a new instance of ReplaceOperationContext.
      *
      */
-    public ReplaceServiceContext()
+    public ReplaceOperationContext()
     {
     	super();
     }
 
     /**
      * 
-     * Creates a new instance of ReplaceServiceContext.
+     * Creates a new instance of ReplaceOperationContext.
      *
      */
-    public ReplaceServiceContext( LdapDN oldDn, LdapDN parent )
+    public ReplaceOperationContext( LdapDN oldDn, LdapDN parent )
     {
         super( oldDn );
         this.parent = parent;

Copied: directory/apacheds/trunk/core/src/main/java/org/apache/directory/server/core/interceptor/context/UnbindOperationContext.java (from r528981, directory/apacheds/trunk/core/src/main/java/org/apache/directory/server/core/interceptor/context/UnbindServiceContext.java)
URL: http://svn.apache.org/viewvc/directory/apacheds/trunk/core/src/main/java/org/apache/directory/server/core/interceptor/context/UnbindOperationContext.java?view=diff&rev=529046&p1=directory/apacheds/trunk/core/src/main/java/org/apache/directory/server/core/interceptor/context/UnbindServiceContext.java&r1=528981&p2=directory/apacheds/trunk/core/src/main/java/org/apache/directory/server/core/interceptor/context/UnbindOperationContext.java&r2=529046
==============================================================================
--- directory/apacheds/trunk/core/src/main/java/org/apache/directory/server/core/jndi/AbstractContextFactory.java (original)
+++ directory/apacheds/trunk/core/src/main/java/org/apache/directory/server/core/jndi/AbstractContextFactory.java Sun Apr 15 12:08:12 2007
@@ -36,8 +36,8 @@
 import org.apache.directory.server.core.configuration.ShutdownConfiguration;
 import org.apache.directory.server.core.configuration.StartupConfiguration;
 import org.apache.directory.server.core.configuration.SyncConfiguration;
-import org.apache.directory.server.core.interceptor.context.AddContextPartitionServiceContext;
-import org.apache.directory.server.core.interceptor.context.RemoveContextPartitionServiceContext;
+import org.apache.directory.server.core.interceptor.context.AddContextPartitionOperationContext;
+import org.apache.directory.server.core.interceptor.context.RemoveContextPartitionOperationContext;
 import org.apache.directory.server.core.partition.PartitionNexusProxy;
 import org.apache.directory.shared.ldap.name.LdapDN;
 import org.apache.directory.shared.ldap.util.StringTools;
@@ -124,8 +124,8 @@
         }
         else if ( cfg instanceof AddPartitionConfiguration )
         {
-            AddContextPartitionServiceContext ctxPartition = 
-                new AddContextPartitionServiceContext( ( ( AddPartitionConfiguration ) cfg ).getDirectoryPartitionConfiguration() );
+            AddContextPartitionOperationContext ctxPartition = 
+                new AddContextPartitionOperationContext( ( ( AddPartitionConfiguration ) cfg ).getDirectoryPartitionConfiguration() );
             
             Context ctx = service.getJndiContext( principalDn, principal, credential, authentication, "" ); 
             
@@ -136,7 +136,7 @@
             Context ctx = service.getJndiContext( principalDn, principal, credential, authentication, "" );
             PartitionNexusProxy proxy = new PartitionNexusProxy( ctx, service );
             proxy.removeContextPartition( 
-                new RemoveContextPartitionServiceContext( ( ( RemovePartitionConfiguration ) cfg ).getSuffix() ) );
+                new RemoveContextPartitionOperationContext( ( ( RemovePartitionConfiguration ) cfg ).getSuffix() ) );
         }
         else if ( service == null )
         {

Modified: directory/apacheds/trunk/core/src/main/java/org/apache/directory/server/core/jndi/ServerContext.java
URL: http://svn.apache.org/viewvc/directory/apacheds/trunk/core/src/main/java/org/apache/directory/server/core/jndi/ServerContext.java?view=diff&rev=529046&r1=529045&r2=529046
==============================================================================
--- directory/apacheds/trunk/core/src/main/java/org/apache/directory/server/core/jndi/ServerContext.java (original)
+++ directory/apacheds/trunk/core/src/main/java/org/apache/directory/server/core/jndi/ServerContext.java Sun Apr 15 12:08:12 2007
@@ -49,14 +49,15 @@
 import org.apache.directory.server.core.DirectoryServiceConfiguration;
 import org.apache.directory.server.core.authn.AuthenticationService;
 import org.apache.directory.server.core.authn.LdapPrincipal;
-import org.apache.directory.server.core.interceptor.context.AddServiceContext;
-import org.apache.directory.server.core.interceptor.context.BindServiceContext;
-import org.apache.directory.server.core.interceptor.context.DeleteServiceContext;
-import org.apache.directory.server.core.interceptor.context.EntryServiceContext;
-import org.apache.directory.server.core.interceptor.context.LookupServiceContext;
-import org.apache.directory.server.core.interceptor.context.RenameServiceContext;
-import org.apache.directory.server.core.interceptor.context.MoveAndRenameServiceContext;
-import org.apache.directory.server.core.interceptor.context.MoveServiceContext;
+import org.apache.directory.server.core.interceptor.context.AddOperationContext;
+import org.apache.directory.server.core.interceptor.context.BindOperationContext;
+import org.apache.directory.server.core.interceptor.context.DeleteOperationContext;
+import org.apache.directory.server.core.interceptor.context.EntryOperationContext;
+import org.apache.directory.server.core.interceptor.context.ListOperationContext;
+import org.apache.directory.server.core.interceptor.context.LookupOperationContext;
+import org.apache.directory.server.core.interceptor.context.RenameOperationContext;
+import org.apache.directory.server.core.interceptor.context.MoveAndRenameOperationContext;
+import org.apache.directory.server.core.interceptor.context.MoveOperationContext;
 import org.apache.directory.server.core.partition.PartitionNexus;
 import org.apache.directory.server.core.partition.PartitionNexusProxy;
 import org.apache.directory.shared.ldap.constants.JndiPropertyConstants;
@@ -132,7 +133,7 @@
         LdapJndiProperties props = LdapJndiProperties.getLdapJndiProperties( this.env );
         dn = props.getProviderDn();
         
-        BindServiceContext bindContext = new BindServiceContext();
+        BindOperationContext bindContext = new BindOperationContext();
         bindContext.setDn( props.getBindDn() );
         bindContext.setCredentials( props.getCredentials() );
         bindContext.setMechanisms( props.getAuthenticationMechanisms() );
@@ -141,7 +142,7 @@
         // need to issue a bind operation here
         this.nexusProxy.bind( bindContext ); 
 
-        if ( ! nexusProxy.hasEntry( new EntryServiceContext( dn ) ) )
+        if ( ! nexusProxy.hasEntry( new EntryOperationContext( dn ) ) )
         {
             throw new NameNotFoundException( dn + " does not exist" );
         }
@@ -321,7 +322,7 @@
          * we need to copy over the controls as well to propagate the complete 
          * environment besides whats in the hashtable for env.
          */
-        nexusProxy.add( new AddServiceContext( target, attributes ) );
+        nexusProxy.add( new AddOperationContext( target, attributes ) );
         return new ServerLdapContext( service, principal, target );
     }
 
@@ -347,7 +348,7 @@
             throw new LdapNoPermissionException( "can't delete the rootDSE" );
         }
 
-        nexusProxy.delete( new DeleteServiceContext( target ) );
+        nexusProxy.delete( new DeleteOperationContext( target ) );
     }
 
 
@@ -391,7 +392,7 @@
         if ( outAttrs != null )
         {
             LdapDN target = buildTarget( name );
-            nexusProxy.add( new AddServiceContext( target, outAttrs ) );
+            nexusProxy.add( new AddOperationContext( target, outAttrs ) );
             return;
         }
 
@@ -426,7 +427,7 @@
 
             // Serialize object into entry attributes and add it.
             JavaLdapSupport.serialize( attributes, obj );
-            nexusProxy.add( new AddServiceContext( target, attributes ) );
+            nexusProxy.add( new AddOperationContext( target, attributes ) );
         }
         else if ( obj instanceof DirContext )
         {
@@ -443,7 +444,7 @@
 
             LdapDN target = buildTarget( name );
             injectRdnAttributeValues( target, attributes );
-            nexusProxy.add( new AddServiceContext( target, attributes ) );
+            nexusProxy.add( new AddOperationContext( target, attributes ) );
         }
         else
         {
@@ -506,7 +507,7 @@
          */
         if ( ( oldName.size() == newName.size() ) && oldBase.equals( newBase ) )
         {
-            nexusProxy.rename( new RenameServiceContext( oldDn, newRdn, delOldRdn ) );
+            nexusProxy.rename( new RenameOperationContext( oldDn, newRdn, delOldRdn ) );
         }
         else
         {
@@ -515,11 +516,11 @@
             
             if ( newRdn.equalsIgnoreCase( oldRdn ) )
             {
-                nexusProxy.move( new MoveServiceContext( oldDn, target ) );
+                nexusProxy.move( new MoveOperationContext( oldDn, target ) );
             }
             else
             {
-                nexusProxy.moveAndRename( new MoveAndRenameServiceContext( oldDn, target, newRdn, delOldRdn ) );
+                nexusProxy.moveAndRename( new MoveAndRenameOperationContext( oldDn, target, newRdn, delOldRdn ) );
             }
         }
     }
@@ -541,9 +542,9 @@
     {
         LdapDN target = buildTarget( name );
         
-        if ( nexusProxy.hasEntry( new EntryServiceContext( target ) ) )
+        if ( nexusProxy.hasEntry( new EntryOperationContext( target ) ) )
         {
-            nexusProxy.delete( new DeleteServiceContext( target ) );
+            nexusProxy.delete( new DeleteOperationContext( target ) );
         }
         
         bind( name, obj );
@@ -564,7 +565,7 @@
      */
     public void unbind( Name name ) throws NamingException
     {
-        nexusProxy.delete( new DeleteServiceContext( buildTarget( name ) ) );
+        nexusProxy.delete( new DeleteOperationContext( buildTarget( name ) ) );
     }
 
 
@@ -592,7 +593,7 @@
         Object obj;
         LdapDN target = buildTarget( name );
         
-        Attributes attributes = nexusProxy.lookup( new LookupServiceContext( target ) );
+        Attributes attributes = nexusProxy.lookup( new LookupOperationContext( target ) );
 
         try
         {
@@ -706,7 +707,7 @@
      */
     public NamingEnumeration list( Name name ) throws NamingException
     {
-        return nexusProxy.list( buildTarget( name ) );
+        return nexusProxy.list( new ListOperationContext( buildTarget( name ) ) );
     }
 
 

Modified: directory/apacheds/trunk/core/src/main/java/org/apache/directory/server/core/jndi/ServerDirContext.java
URL: http://svn.apache.org/viewvc/directory/apacheds/trunk/core/src/main/java/org/apache/directory/server/core/jndi/ServerDirContext.java?view=diff&rev=529046&r1=529045&r2=529046
==============================================================================
--- directory/apacheds/trunk/core/src/main/java/org/apache/directory/server/core/jndi/ServerDirContext.java (original)
+++ directory/apacheds/trunk/core/src/main/java/org/apache/directory/server/core/jndi/ServerDirContext.java Sun Apr 15 12:08:12 2007
@@ -44,12 +44,12 @@
 
 import org.apache.directory.server.core.DirectoryService;
 import org.apache.directory.server.core.authn.LdapPrincipal;
-import org.apache.directory.server.core.interceptor.context.AddServiceContext;
-import org.apache.directory.server.core.interceptor.context.DeleteServiceContext;
-import org.apache.directory.server.core.interceptor.context.EntryServiceContext;
-import org.apache.directory.server.core.interceptor.context.LookupServiceContext;
-import org.apache.directory.server.core.interceptor.context.ModifyServiceContext;
-import org.apache.directory.server.core.interceptor.context.ServiceContext;
+import org.apache.directory.server.core.interceptor.context.AddOperationContext;
+import org.apache.directory.server.core.interceptor.context.DeleteOperationContext;
+import org.apache.directory.server.core.interceptor.context.EntryOperationContext;
+import org.apache.directory.server.core.interceptor.context.LookupOperationContext;
+import org.apache.directory.server.core.interceptor.context.ModifyOperationContext;
+import org.apache.directory.server.core.interceptor.context.OperationContext;
 import org.apache.directory.server.core.partition.PartitionNexusProxy;
 import org.apache.directory.shared.ldap.constants.SchemaConstants;
 import org.apache.directory.shared.ldap.filter.AssertionEnum;
@@ -123,7 +123,7 @@
      */
     public Attributes getAttributes( Name name ) throws NamingException
     {
-        LookupServiceContext lookupContext = new LookupServiceContext( buildTarget( name ) );
+        LookupOperationContext lookupContext = new LookupOperationContext( buildTarget( name ) );
 
         return getNexusProxy().lookup( lookupContext );
     }
@@ -145,7 +145,7 @@
      */
     public Attributes getAttributes( Name name, String[] attrIds ) throws NamingException
     {
-        LookupServiceContext lookupContext = new LookupServiceContext( buildTarget( name ), attrIds );
+        LookupOperationContext lookupContext = new LookupOperationContext( buildTarget( name ), attrIds );
         
         return getNexusProxy().lookup( lookupContext );
     }
@@ -168,11 +168,11 @@
     {
     	if ( name instanceof LdapDN )
     	{
-    		getNexusProxy().modify( new ModifyServiceContext( buildTarget( name ), modOp, attrs ) );
+    		getNexusProxy().modify( new ModifyOperationContext( buildTarget( name ), modOp, attrs ) );
     	}
     	else
     	{
-    		getNexusProxy().modify( new ModifyServiceContext( buildTarget( new LdapDN( name ) ), modOp, attrs ) );
+    		getNexusProxy().modify( new ModifyOperationContext( buildTarget( new LdapDN( name ) ), modOp, attrs ) );
     	}
     }
 
@@ -264,7 +264,7 @@
         {
             Attributes clone = ( Attributes ) attrs.clone();
             LdapDN target = buildTarget( name );
-            getNexusProxy().add( new AddServiceContext( target, clone ) );
+            getNexusProxy().add( new AddOperationContext( target, clone ) );
             return;
         }
 
@@ -284,7 +284,7 @@
                     attributes.put( ( Attribute ) list.next() );
                 }
             }
-            getNexusProxy().add( new AddServiceContext( target, attributes ) );
+            getNexusProxy().add( new AddOperationContext( target, attributes ) );
             return;
         }
 
@@ -316,7 +316,7 @@
 
             // Serialize object into entry attributes and add it.
             JavaLdapSupport.serialize( attributes, obj );
-            getNexusProxy().add( new AddServiceContext( target, attributes ) );
+            getNexusProxy().add( new AddOperationContext( target, attributes ) );
         }
         else if ( obj instanceof DirContext )
         {
@@ -331,7 +331,7 @@
                 }
             }
             LdapDN target = buildTarget( name );
-            getNexusProxy().add( new AddServiceContext( target, attributes ) );
+            getNexusProxy().add( new AddOperationContext( target, attributes ) );
         }
         else
         {
@@ -357,9 +357,9 @@
     public void rebind( Name name, Object obj, Attributes attrs ) throws NamingException
     {
         LdapDN target = buildTarget( name );
-        if ( getNexusProxy().hasEntry( new EntryServiceContext( target ) ) )
+        if ( getNexusProxy().hasEntry( new EntryOperationContext( target ) ) )
         {
-            getNexusProxy().delete( new DeleteServiceContext( target ) );
+            getNexusProxy().delete( new DeleteOperationContext( target ) );
         }
         bind( name, obj, attrs );
     }
@@ -425,7 +425,7 @@
         }
 
         // Add the new context to the server which as a side effect adds
-        getNexusProxy().add( new AddServiceContext( target, attributes ) );
+        getNexusProxy().add( new AddOperationContext( target, attributes ) );
 
         // Initialize the new context
         return new ServerLdapContext( getService(), getPrincipal(), target );

Modified: directory/apacheds/trunk/core/src/main/java/org/apache/directory/server/core/jndi/ServerLdapContext.java
URL: http://svn.apache.org/viewvc/directory/apacheds/trunk/core/src/main/java/org/apache/directory/server/core/jndi/ServerLdapContext.java?view=diff&rev=529046&r1=529045&r2=529046
==============================================================================
--- directory/apacheds/trunk/core/src/main/java/org/apache/directory/server/core/jndi/ServerLdapContext.java (original)
+++ directory/apacheds/trunk/core/src/main/java/org/apache/directory/server/core/jndi/ServerLdapContext.java Sun Apr 15 12:08:12 2007
@@ -31,8 +31,8 @@
 
 import org.apache.directory.server.core.DirectoryService;
 import org.apache.directory.server.core.authn.LdapPrincipal;
-import org.apache.directory.server.core.interceptor.context.CompareServiceContext;
-import org.apache.directory.server.core.interceptor.context.UnbindServiceContext;
+import org.apache.directory.server.core.interceptor.context.CompareOperationContext;
+import org.apache.directory.server.core.interceptor.context.UnbindOperationContext;
 import org.apache.directory.server.core.referral.ReferralService;
 import org.apache.directory.shared.ldap.NotImplementedException;
 import org.apache.directory.shared.ldap.name.LdapDN;
@@ -165,7 +165,7 @@
      */
     public boolean compare( LdapDN name, String oid, Object value ) throws NamingException
     {
-        return super.getNexusProxy().compare( new CompareServiceContext( name, oid, value ) );
+        return super.getNexusProxy().compare( new CompareOperationContext( name, oid, value ) );
     }
 
 
@@ -181,7 +181,7 @@
     {
         String bindDn = ( String ) getEnvironment().get( Context.SECURITY_PRINCIPAL );
         
-        super.getNexusProxy().unbind( new UnbindServiceContext( new LdapDN( bindDn ) ) );
+        super.getNexusProxy().unbind( new UnbindOperationContext( new LdapDN( bindDn ) ) );
     }
 
 

Modified: directory/apacheds/trunk/core/src/main/java/org/apache/directory/server/core/normalization/NormalizationService.java
URL: http://svn.apache.org/viewvc/directory/apacheds/trunk/core/src/main/java/org/apache/directory/server/core/normalization/NormalizationService.java?view=diff&rev=529046&r1=529045&r2=529046
==============================================================================
--- directory/apacheds/trunk/core/src/main/java/org/apache/directory/server/core/normalization/NormalizationService.java (original)
+++ directory/apacheds/trunk/core/src/main/java/org/apache/directory/server/core/normalization/NormalizationService.java Sun Apr 15 12:08:12 2007
@@ -33,10 +33,10 @@
 import org.apache.directory.server.core.configuration.InterceptorConfiguration;
 import org.apache.directory.server.core.interceptor.BaseInterceptor;
 import org.apache.directory.server.core.interceptor.NextInterceptor;
-import org.apache.directory.server.core.interceptor.context.LookupServiceContext;
-import org.apache.directory.server.core.interceptor.context.MoveAndRenameServiceContext;
-import org.apache.directory.server.core.interceptor.context.MoveServiceContext;
-import org.apache.directory.server.core.interceptor.context.ServiceContext;
+import org.apache.directory.server.core.interceptor.context.LookupOperationContext;
+import org.apache.directory.server.core.interceptor.context.MoveAndRenameOperationContext;
+import org.apache.directory.server.core.interceptor.context.MoveOperationContext;
+import org.apache.directory.server.core.interceptor.context.OperationContext;
 import org.apache.directory.server.core.partition.PartitionNexus;
 import org.apache.directory.server.schema.ConcreteNameComponentNormalizer;
 import org.apache.directory.server.schema.registries.AttributeTypeRegistry;
@@ -110,26 +110,26 @@
     // Normalize all Name based arguments for ContextPartition interface operations
     // ------------------------------------------------------------------------
 
-    public void add(NextInterceptor nextInterceptor, ServiceContext addContext)
+    public void add(NextInterceptor nextInterceptor, OperationContext opContext)
         throws NamingException
     {
-        LdapDN.normalize( addContext.getDn(), attrNormalizers );
-        nextInterceptor.add( addContext );
+        LdapDN.normalize( opContext.getDn(), attrNormalizers );
+        nextInterceptor.add( opContext );
     }
 
 
-    public void delete( NextInterceptor nextInterceptor, ServiceContext deleteContext ) throws NamingException
+    public void delete( NextInterceptor nextInterceptor, OperationContext opContext ) throws NamingException
     {
-        LdapDN.normalize( deleteContext.getDn(), attrNormalizers );
-        nextInterceptor.delete( deleteContext );
+        LdapDN.normalize( opContext.getDn(), attrNormalizers );
+        nextInterceptor.delete( opContext );
     }
 
 
-    public void modify( NextInterceptor nextInterceptor, ServiceContext modifyContext )
+    public void modify( NextInterceptor nextInterceptor, OperationContext opContext )
         throws NamingException
     {
-        LdapDN.normalize( modifyContext.getDn(), attrNormalizers );
-        nextInterceptor.modify( modifyContext );
+        LdapDN.normalize( opContext.getDn(), attrNormalizers );
+        nextInterceptor.modify( opContext );
     }
 
 
@@ -140,28 +140,28 @@
     }
 
 
-    public void rename( NextInterceptor nextInterceptor, ServiceContext renameContext )
+    public void rename( NextInterceptor nextInterceptor, OperationContext opContext )
         throws NamingException
     {
-        LdapDN.normalize( renameContext.getDn(), attrNormalizers );
-        nextInterceptor.rename( renameContext );
+        LdapDN.normalize( opContext.getDn(), attrNormalizers );
+        nextInterceptor.rename( opContext );
     }
 
 
-    public void move( NextInterceptor nextInterceptor, ServiceContext moveContext ) throws NamingException
+    public void move( NextInterceptor nextInterceptor, OperationContext opContext ) throws NamingException
     {
-        LdapDN.normalize( moveContext.getDn(), attrNormalizers );
-        ((MoveServiceContext)moveContext).getParent().normalize( attrNormalizers);
-        nextInterceptor.move( moveContext );
+        LdapDN.normalize( opContext.getDn(), attrNormalizers );
+        ((MoveOperationContext)opContext).getParent().normalize( attrNormalizers);
+        nextInterceptor.move( opContext );
     }
 
 
-    public void moveAndRename( NextInterceptor nextInterceptor, ServiceContext moveAndRenameContext )
+    public void moveAndRename( NextInterceptor nextInterceptor, OperationContext opContext )
         throws NamingException
     {
-        LdapDN.normalize( moveAndRenameContext.getDn(), attrNormalizers );
-        LdapDN.normalize( ((MoveAndRenameServiceContext)moveAndRenameContext).getParent(), attrNormalizers);
-        nextInterceptor.moveAndRename( moveAndRenameContext );
+        LdapDN.normalize( opContext.getDn(), attrNormalizers );
+        LdapDN.normalize( ((MoveAndRenameOperationContext)opContext).getParent(), attrNormalizers);
+        nextInterceptor.moveAndRename( opContext );
     }
 
 
@@ -345,24 +345,24 @@
     }
 
 
-    public boolean hasEntry( NextInterceptor nextInterceptor, ServiceContext entryContext ) throws NamingException
+    public boolean hasEntry( NextInterceptor nextInterceptor, OperationContext opContext ) throws NamingException
     {
-        LdapDN.normalize( entryContext.getDn(), attrNormalizers );
-        return nextInterceptor.hasEntry( entryContext );
+        LdapDN.normalize( opContext.getDn(), attrNormalizers );
+        return nextInterceptor.hasEntry( opContext );
     }
 
 
-    public NamingEnumeration list( NextInterceptor nextInterceptor, LdapDN base ) throws NamingException
+    public NamingEnumeration list( NextInterceptor nextInterceptor, OperationContext opContext ) throws NamingException
     {
-        base = LdapDN.normalize( base, attrNormalizers );
-        return nextInterceptor.list( base );
+        LdapDN.normalize( opContext.getDn(), attrNormalizers );
+        return nextInterceptor.list( opContext );
     }
 
 
-    public Attributes lookup( NextInterceptor nextInterceptor, ServiceContext lookupContext ) throws NamingException
+    public Attributes lookup( NextInterceptor nextInterceptor, OperationContext opContext ) throws NamingException
     {
-        LdapDN.normalize( ((LookupServiceContext)lookupContext).getDn(), attrNormalizers );
-        return nextInterceptor.lookup( lookupContext );
+        LdapDN.normalize( ((LookupOperationContext)opContext).getDn(), attrNormalizers );
+        return nextInterceptor.lookup( opContext );
     }
 
 
@@ -370,43 +370,43 @@
     // Normalize all Name based arguments for other interface operations
     // ------------------------------------------------------------------------
 
-    public LdapDN getMatchedName ( NextInterceptor nextInterceptor, ServiceContext getMatchedNameContext ) throws NamingException
+    public LdapDN getMatchedName ( NextInterceptor nextInterceptor, OperationContext opContext ) throws NamingException
     {
-        LdapDN.normalize( getMatchedNameContext.getDn(), attrNormalizers );
-        return nextInterceptor.getMatchedName( getMatchedNameContext );
+        LdapDN.normalize( opContext.getDn(), attrNormalizers );
+        return nextInterceptor.getMatchedName( opContext );
     }
 
 
-    public LdapDN getSuffix ( NextInterceptor nextInterceptor, ServiceContext getSuffixContext ) throws NamingException
+    public LdapDN getSuffix ( NextInterceptor nextInterceptor, OperationContext opContext ) throws NamingException
     {
-        LdapDN.normalize( getSuffixContext.getDn(), attrNormalizers );
-        return nextInterceptor.getSuffix( getSuffixContext );
+        LdapDN.normalize( opContext.getDn(), attrNormalizers );
+        return nextInterceptor.getSuffix( opContext );
     }
 
 
-    public boolean compare( NextInterceptor next, ServiceContext compareContext ) throws NamingException
+    public boolean compare( NextInterceptor next, OperationContext opContext ) throws NamingException
     {
-        LdapDN.normalize( compareContext.getDn(), attrNormalizers );
-        return next.compare( compareContext );
+        LdapDN.normalize( opContext.getDn(), attrNormalizers );
+        return next.compare( opContext );
     }
     
     
-    public void bind( NextInterceptor next, ServiceContext ctx )  throws NamingException
+    public void bind( NextInterceptor next, OperationContext opContext )  throws NamingException
     {
-        LdapDN.normalize(ctx.getDn(), attrNormalizers );
-        next.bind( ctx );
+        LdapDN.normalize( opContext.getDn(), attrNormalizers );
+        next.bind( opContext );
     }
 
 
-    public void addContextPartition( NextInterceptor next, ServiceContext addContextPartitionContext ) throws NamingException
+    public void addContextPartition( NextInterceptor next, OperationContext opContext ) throws NamingException
     {
-        next.addContextPartition( addContextPartitionContext );
+        next.addContextPartition( opContext );
     }
 
 
-    public void removeContextPartition( NextInterceptor next, ServiceContext removeContextPartition ) throws NamingException
+    public void removeContextPartition( NextInterceptor next, OperationContext opContext ) throws NamingException
     {
-        LdapDN.normalize( removeContextPartition.getDn(), attrNormalizers );
-        next.removeContextPartition( removeContextPartition );
+        LdapDN.normalize( opContext.getDn(), attrNormalizers );
+        next.removeContextPartition( opContext );
     }
 }

Modified: directory/apacheds/trunk/core/src/main/java/org/apache/directory/server/core/operational/OperationalAttributeService.java
URL: http://svn.apache.org/viewvc/directory/apacheds/trunk/core/src/main/java/org/apache/directory/server/core/operational/OperationalAttributeService.java?view=diff&rev=529046&r1=529045&r2=529046
==============================================================================
--- directory/apacheds/trunk/core/src/main/java/org/apache/directory/server/core/operational/OperationalAttributeService.java (original)
+++ directory/apacheds/trunk/core/src/main/java/org/apache/directory/server/core/operational/OperationalAttributeService.java Sun Apr 15 12:08:12 2007
@@ -42,13 +42,13 @@
 import org.apache.directory.server.core.interceptor.BaseInterceptor;
 import org.apache.directory.server.core.interceptor.Interceptor;
 import org.apache.directory.server.core.interceptor.NextInterceptor;
-import org.apache.directory.server.core.interceptor.context.AddServiceContext;
-import org.apache.directory.server.core.interceptor.context.LookupServiceContext;
-import org.apache.directory.server.core.interceptor.context.RenameServiceContext;
-import org.apache.directory.server.core.interceptor.context.ModifyServiceContext;
-import org.apache.directory.server.core.interceptor.context.MoveAndRenameServiceContext;
-import org.apache.directory.server.core.interceptor.context.MoveServiceContext;
-import org.apache.directory.server.core.interceptor.context.ServiceContext;
+import org.apache.directory.server.core.interceptor.context.AddOperationContext;
+import org.apache.directory.server.core.interceptor.context.LookupOperationContext;
+import org.apache.directory.server.core.interceptor.context.RenameOperationContext;
+import org.apache.directory.server.core.interceptor.context.ModifyOperationContext;
+import org.apache.directory.server.core.interceptor.context.MoveAndRenameOperationContext;
+import org.apache.directory.server.core.interceptor.context.MoveOperationContext;
+import org.apache.directory.server.core.interceptor.context.OperationContext;
 import org.apache.directory.server.core.invocation.Invocation;
 import org.apache.directory.server.core.invocation.InvocationStack;
 import org.apache.directory.server.core.partition.PartitionNexus;
@@ -152,11 +152,11 @@
     /**
      * Adds extra operational attributes to the entry before it is added.
      */
-    public void add(NextInterceptor nextInterceptor, ServiceContext addContext )
+    public void add(NextInterceptor nextInterceptor, OperationContext opContext )
         throws NamingException
     {
         String principal = getPrincipal().getName();
-        Attributes entry = ((AddServiceContext)addContext).getEntry();
+        Attributes entry = ((AddOperationContext)opContext).getEntry();
 
         Attribute attribute = new AttributeImpl( SchemaConstants.CREATORS_NAME_AT );
         attribute.add( principal );
@@ -166,16 +166,16 @@
         attribute.add( DateUtils.getGeneralizedTime() );
         entry.put( attribute );
 
-        nextInterceptor.add( addContext );
+        nextInterceptor.add( opContext );
     }
 
 
-    public void modify( NextInterceptor nextInterceptor, ServiceContext modifyContext )
+    public void modify( NextInterceptor nextInterceptor, OperationContext opContext )
         throws NamingException
     {
-        nextInterceptor.modify( modifyContext );
+        nextInterceptor.modify( opContext );
 
-        if ( modifyContext.getDn().getNormName().equals( subschemaSubentryDn.getNormName() ) ) 
+        if ( opContext.getDn().getNormName().equals( subschemaSubentryDn.getNormName() ) ) 
         {
             return;
         }
@@ -190,8 +190,8 @@
         attribute.add( DateUtils.getGeneralizedTime() );
         attributes.put( attribute );
 
-        ModifyServiceContext newModify = new ModifyServiceContext( 
-        		modifyContext.getDn(),
+        ModifyOperationContext newModify = new ModifyOperationContext( 
+            opContext.getDn(),
         		DirContext.REPLACE_ATTRIBUTE, 
         		attributes);
         nexus.modify( newModify );
@@ -217,7 +217,7 @@
         attribute.add( DateUtils.getGeneralizedTime() );
         attributes.put( attribute );
 
-        ModifyServiceContext newModify = new ModifyServiceContext( 
+        ModifyOperationContext newModify = new ModifyOperationContext( 
         		name,
         		DirContext.REPLACE_ATTRIBUTE, 
         		attributes);
@@ -225,10 +225,10 @@
     }
 
 
-    public void rename( NextInterceptor nextInterceptor, ServiceContext renameContext )
+    public void rename( NextInterceptor nextInterceptor, OperationContext opContext )
         throws NamingException
     {
-        nextInterceptor.rename( renameContext );
+        nextInterceptor.rename( opContext );
 
         // add operational attributes after call in case the operation fails
         Attributes attributes = new AttributesImpl( true );
@@ -240,12 +240,12 @@
         attribute.add( DateUtils.getGeneralizedTime() );
         attributes.put( attribute );
 
-        LdapDN newDn = ( LdapDN ) renameContext.getDn().clone();
-        newDn.remove( renameContext.getDn().size() - 1 );
-        newDn.add( ((RenameServiceContext)renameContext).getNewRdn() );
+        LdapDN newDn = ( LdapDN ) opContext.getDn().clone();
+        newDn.remove( opContext.getDn().size() - 1 );
+        newDn.add( ((RenameOperationContext)opContext).getNewRdn() );
         newDn.normalize( registry.getNormalizerMapping() );
         
-        ModifyServiceContext newModify = new ModifyServiceContext( 
+        ModifyOperationContext newModify = new ModifyOperationContext( 
         		newDn,
         		DirContext.REPLACE_ATTRIBUTE, 
         		attributes);
@@ -254,9 +254,9 @@
     }
 
 
-    public void move( NextInterceptor nextInterceptor, ServiceContext moveContext ) throws NamingException
+    public void move( NextInterceptor nextInterceptor, OperationContext opContext ) throws NamingException
     {
-        nextInterceptor.move( moveContext );
+        nextInterceptor.move( opContext );
 
         // add operational attributes after call in case the operation fails
         Attributes attributes = new AttributesImpl( true );
@@ -268,8 +268,8 @@
         attribute.add( DateUtils.getGeneralizedTime() );
         attributes.put( attribute );
 
-        ModifyServiceContext newModify = new ModifyServiceContext( 
-        		((MoveServiceContext)moveContext).getParent(),
+        ModifyOperationContext newModify = new ModifyOperationContext( 
+        		((MoveOperationContext)opContext).getParent(),
         		DirContext.REPLACE_ATTRIBUTE, 
         		attributes);
         
@@ -277,10 +277,10 @@
     }
 
 
-    public void moveAndRename( NextInterceptor nextInterceptor, ServiceContext moveAndRenameContext )
+    public void moveAndRename( NextInterceptor nextInterceptor, OperationContext opContext )
         throws NamingException
     {
-        nextInterceptor.moveAndRename( moveAndRenameContext );
+        nextInterceptor.moveAndRename( opContext );
 
         // add operational attributes after call in case the operation fails
         Attributes attributes = new AttributesImpl( true );
@@ -292,39 +292,39 @@
         attribute.add( DateUtils.getGeneralizedTime() );
         attributes.put( attribute );
 
-        ModifyServiceContext newModify = new ModifyServiceContext( 
-        		((MoveAndRenameServiceContext)moveAndRenameContext).getParent(),
+        ModifyOperationContext newModify = new ModifyOperationContext( 
+        		((MoveAndRenameOperationContext)opContext).getParent(),
         		DirContext.REPLACE_ATTRIBUTE, 
         		attributes);
         nexus.modify( newModify );
     }
 
 
-    public Attributes lookup( NextInterceptor nextInterceptor, ServiceContext lookupContext ) throws NamingException
+    public Attributes lookup( NextInterceptor nextInterceptor, OperationContext opContext ) throws NamingException
     {
-        Attributes result = nextInterceptor.lookup( lookupContext );
+        Attributes result = nextInterceptor.lookup( opContext );
         
         if ( result == null )
         {
             return null;
         }
 
-        if ( ((LookupServiceContext)lookupContext).getAttrsId() == null )
+        if ( ((LookupOperationContext)opContext).getAttrsId() == null )
         {
             filter( result );
         }
         else
         {
-            filter( lookupContext, result );
+            filter( opContext, result );
         }
         
         return result;
     }
 
 
-    public NamingEnumeration list( NextInterceptor nextInterceptor, LdapDN base ) throws NamingException
+    public NamingEnumeration list( NextInterceptor nextInterceptor, OperationContext opContext ) throws NamingException
     {
-        NamingEnumeration e = nextInterceptor.list( base );
+        NamingEnumeration e = nextInterceptor.list( opContext );
         Invocation invocation = InvocationStack.getInstance().peek();
         return new SearchResultFilteringEnumeration( e, new SearchControls(), invocation, SEARCH_FILTER );
     }
@@ -380,10 +380,10 @@
     }
 
 
-    private void filter( ServiceContext lookupContext, Attributes entry ) throws NamingException
+    private void filter( OperationContext lookupContext, Attributes entry ) throws NamingException
     {
-        LdapDN dn = ((LookupServiceContext)lookupContext).getDn();
-        List<String> ids = ((LookupServiceContext)lookupContext).getAttrsId();
+        LdapDN dn = ((LookupOperationContext)lookupContext).getDn();
+        List<String> ids = ((LookupOperationContext)lookupContext).getAttrsId();
         
         // still need to protect against returning op attrs when ids is null
         if ( ids == null )

Modified: directory/apacheds/trunk/core/src/main/java/org/apache/directory/server/core/partition/AbstractPartition.java
URL: http://svn.apache.org/viewvc/directory/apacheds/trunk/core/src/main/java/org/apache/directory/server/core/partition/AbstractPartition.java?view=diff&rev=529046&r1=529045&r2=529046
==============================================================================
--- directory/apacheds/trunk/core/src/main/java/org/apache/directory/server/core/partition/DefaultPartitionNexus.java (original)
+++ directory/apacheds/trunk/core/src/main/java/org/apache/directory/server/core/partition/DefaultPartitionNexus.java Sun Apr 15 12:08:12 2007
@@ -44,12 +44,12 @@
 
 import org.apache.directory.server.core.DirectoryServiceConfiguration;
 import org.apache.directory.server.core.configuration.PartitionConfiguration;
-import org.apache.directory.server.core.interceptor.context.AddContextPartitionServiceContext;
-import org.apache.directory.server.core.interceptor.context.CompareServiceContext;
-import org.apache.directory.server.core.interceptor.context.EntryServiceContext;
-import org.apache.directory.server.core.interceptor.context.LookupServiceContext;
-import org.apache.directory.server.core.interceptor.context.RemoveContextPartitionServiceContext;
-import org.apache.directory.server.core.interceptor.context.ServiceContext;
+import org.apache.directory.server.core.interceptor.context.AddContextPartitionOperationContext;
+import org.apache.directory.server.core.interceptor.context.CompareOperationContext;
+import org.apache.directory.server.core.interceptor.context.EntryOperationContext;
+import org.apache.directory.server.core.interceptor.context.LookupOperationContext;
+import org.apache.directory.server.core.interceptor.context.RemoveContextPartitionOperationContext;
+import org.apache.directory.server.core.interceptor.context.OperationContext;
 import org.apache.directory.server.core.partition.impl.btree.MutableBTreePartitionConfiguration;
 import org.apache.directory.server.core.partition.impl.btree.jdbm.JdbmPartition;
 import org.apache.directory.server.schema.registries.AttributeTypeRegistry;
@@ -212,7 +212,7 @@
             while ( i.hasNext() )
             {
                 PartitionConfiguration c = ( PartitionConfiguration ) i.next();
-                addContextPartition( new AddContextPartitionServiceContext( c ) );
+                addContextPartition( new AddContextPartitionOperationContext( c ) );
                 initializedPartitionCfgs.add( 0, c );
             }
             initialized = true;
@@ -413,7 +413,7 @@
             
             try
             {
-                removeContextPartition( new RemoveContextPartitionServiceContext( new LdapDN( suffix ) ) );
+                removeContextPartition( new RemoveContextPartitionOperationContext( new LdapDN( suffix ) ) );
             }
             catch ( NamingException e )
             {
@@ -466,12 +466,12 @@
     // ContextPartitionNexus Method Implementations
     // ------------------------------------------------------------------------
 
-    public boolean compare( ServiceContext compareContext ) throws NamingException
+    public boolean compare( OperationContext compareContext ) throws NamingException
     {
         Partition partition = getBackend( compareContext.getDn() );
         AttributeTypeRegistry registry = factoryCfg.getRegistries().getAttributeTypeRegistry();
         
-        CompareServiceContext ctx = (CompareServiceContext)compareContext;
+        CompareOperationContext ctx = (CompareOperationContext)compareContext;
 
         // complain if we do not recognize the attribute being compared
         if ( !registry.hasAttributeType( ctx.getOid() ) )
@@ -481,7 +481,7 @@
 
         AttributeType attrType = registry.lookup( ctx.getOid() );
         
-        Attribute attr = partition.lookup( new LookupServiceContext( ctx.getDn() ) ).get( attrType.getName() );
+        Attribute attr = partition.lookup( new LookupOperationContext( ctx.getDn() ) ).get( attrType.getName() );
 
         // complain if the attribute being compared does not exist in the entry
         if ( attr == null )
@@ -535,9 +535,9 @@
     }
 
 
-    public synchronized void addContextPartition( ServiceContext addContextPartitionContext ) throws NamingException
+    public synchronized void addContextPartition( OperationContext addContextPartitionContext ) throws NamingException
     {
-        PartitionConfiguration config = ((AddContextPartitionServiceContext)addContextPartitionContext).getCfg();
+        PartitionConfiguration config = ((AddContextPartitionOperationContext)addContextPartitionContext).getCfg();
         Partition partition = config.getContextPartition();
 
         // Turn on default indices
@@ -559,7 +559,7 @@
     }
 
 
-    public synchronized void removeContextPartition( ServiceContext removeContextPartition ) throws NamingException
+    public synchronized void removeContextPartition( OperationContext removeContextPartition ) throws NamingException
     {
         String key = removeContextPartition.getDn().getNormName();
         Partition partition = partitions.get( key );
@@ -594,15 +594,15 @@
 
 
     /**
-     * @see PartitionNexus#getMatchedName( ServiceContext )
+     * @see PartitionNexus#getMatchedName( OperationContext )
      */
-    public LdapDN getMatchedName ( ServiceContext getMatchedNameContext ) throws NamingException
+    public LdapDN getMatchedName ( OperationContext getMatchedNameContext ) throws NamingException
     {
         LdapDN dn = ( LdapDN ) getMatchedNameContext.getDn().clone();
         
         while ( dn.size() > 0 )
         {
-            if ( hasEntry( new EntryServiceContext( dn ) ) )
+            if ( hasEntry( new EntryOperationContext( dn ) ) )
             {
                 return dn;
             }
@@ -626,9 +626,9 @@
 
 
     /**
-     * @see PartitionNexus#getSuffix( ServiceContext )
+     * @see PartitionNexus#getSuffix( OperationContext )
      */
-    public LdapDN getSuffix ( ServiceContext getSuffixContext ) throws NamingException
+    public LdapDN getSuffix ( OperationContext getSuffixContext ) throws NamingException
     {
         Partition backend = getBackend( getSuffixContext.getDn() );
         return backend.getSuffix();
@@ -636,15 +636,15 @@
 
 
     /**
-     * @see PartitionNexus#listSuffixes( ServiceContext )
+     * @see PartitionNexus#listSuffixes( OperationContext )
      */
-    public Iterator listSuffixes ( ServiceContext emptyContext ) throws NamingException
+    public Iterator listSuffixes ( OperationContext emptyContext ) throws NamingException
     {
         return Collections.unmodifiableSet( partitions.keySet() ).iterator();
     }
 
 
-    public Attributes getRootDSE( ServiceContext getRootDSEContext )
+    public Attributes getRootDSE( OperationContext getRootDSEContext )
     {
         return rootDSE;
     }
@@ -673,13 +673,13 @@
     // ------------------------------------------------------------------------
     // DirectoryPartition Interface Method Implementations
     // ------------------------------------------------------------------------
-    public void bind( ServiceContext bindContext ) throws NamingException
+    public void bind( OperationContext bindContext ) throws NamingException
     {
         Partition partition = getBackend( bindContext.getDn() );
         partition.bind( bindContext );
     }
 
-    public void unbind( ServiceContext unbindContext ) throws NamingException
+    public void unbind( OperationContext unbindContext ) throws NamingException
     {
         Partition partition = getBackend( unbindContext.getDn() );
         partition.unbind( unbindContext );
@@ -689,7 +689,7 @@
     /**
      * @see Partition#delete(org.apache.directory.shared.ldap.name.LdapDN)
      */
-    public void delete( ServiceContext deleteContext ) throws NamingException
+    public void delete( OperationContext deleteContext ) throws NamingException
     {
         Partition backend = getBackend( deleteContext.getDn() );
         backend.delete( deleteContext );
@@ -703,9 +703,9 @@
      * here so backend implementors do not have to worry about performing these
      * kinds of checks.
      *
-     * @see Partition#add( ServiceContext )
+     * @see Partition#add( OperationContext )
      */
-    public void add( ServiceContext addContext ) throws NamingException
+    public void add( OperationContext addContext ) throws NamingException
     {
         Partition backend = getBackend( addContext.getDn() );
         backend.add( addContext );
@@ -715,7 +715,7 @@
     /**
      * @see Partition#modify(org.apache.directory.shared.ldap.name.LdapDN,int,javax.naming.directory.Attributes)
      */
-    public void modify( ServiceContext modifyContext ) throws NamingException
+    public void modify( OperationContext modifyContext ) throws NamingException
     {
         Partition backend = getBackend( modifyContext.getDn() );
         backend.modify( modifyContext );
@@ -735,10 +735,10 @@
     /**
      * @see Partition#list(org.apache.directory.shared.ldap.name.LdapDN)
      */
-    public NamingEnumeration list( LdapDN base ) throws NamingException
+    public NamingEnumeration list( OperationContext opContext ) throws NamingException
     {
-        Partition backend = getBackend( base );
-        return backend.list( base );
+        Partition backend = getBackend( opContext.getDn() );
+        return backend.list( opContext );
     }
 
 
@@ -891,9 +891,9 @@
     /**
      * @see Partition#lookup(org.apache.directory.shared.ldap.name.LdapDN,String[])
      */
-    public Attributes lookup( ServiceContext lookupContext ) throws NamingException
+    public Attributes lookup( OperationContext opContext ) throws NamingException
     {
-        LookupServiceContext ctx = (LookupServiceContext)lookupContext;
+        LookupOperationContext ctx = (LookupOperationContext)opContext;
         LdapDN dn = ctx.getDn();
         
         if ( dn.size() == 0 )
@@ -934,11 +934,11 @@
 
 
     /**
-     * @see Partition#hasEntry(ServiceContext)
+     * @see Partition#hasEntry(OperationContext)
      */
-    public boolean hasEntry( ServiceContext entryContext ) throws NamingException
+    public boolean hasEntry( OperationContext opContext ) throws NamingException
     {
-        LdapDN dn = entryContext.getDn();
+        LdapDN dn = opContext.getDn();
         
         if ( IS_DEBUG )
         {
@@ -951,37 +951,37 @@
         }
 
         Partition backend = getBackend( dn );
-        return backend.hasEntry( entryContext );
+        return backend.hasEntry( opContext );
     }
 
 
     /**
-     * @see Partition#rename(ServiceContext)
+     * @see Partition#rename(OperationContext)
      */
-    public void rename( ServiceContext renameContext ) throws NamingException
+    public void rename( OperationContext opContext ) throws NamingException
     {
-        Partition backend = getBackend( renameContext.getDn() );
-        backend.rename( renameContext );
+        Partition backend = getBackend( opContext.getDn() );
+        backend.rename( opContext );
     }
 
 
     /**
-     * @see Partition#move(ServiceContext)
+     * @see Partition#move(OperationContext)
      */
-    public void move( ServiceContext moveContext ) throws NamingException
+    public void move( OperationContext opContext ) throws NamingException
     {
-        Partition backend = getBackend( moveContext.getDn() );
-        backend.move( moveContext );
+        Partition backend = getBackend( opContext.getDn() );
+        backend.move( opContext );
     }
 
 
     /**
-     * @see Partition#moveAndRename( ServiceContext )
+     * @see Partition#moveAndRename( OperationContext )
      */
-    public void moveAndRename( ServiceContext moveAndRenameContext ) throws NamingException
+    public void moveAndRename( OperationContext opContext ) throws NamingException
     {
-        Partition backend = getBackend( moveAndRenameContext.getDn() );
-        backend.moveAndRename( moveAndRenameContext );
+        Partition backend = getBackend( opContext.getDn() );
+        backend.moveAndRename( opContext );
     }
 
 

Modified: directory/apacheds/trunk/core/src/main/java/org/apache/directory/server/core/partition/Partition.java
URL: http://svn.apache.org/viewvc/directory/apacheds/trunk/core/src/main/java/org/apache/directory/server/core/partition/Partition.java?view=diff&rev=529046&r1=529045&r2=529046
==============================================================================
--- directory/apacheds/trunk/core/src/main/java/org/apache/directory/server/core/interceptor/context/GetSuffixServiceContext.java (original)
+++ directory/apacheds/trunk/core/src/main/java/org/apache/directory/server/core/interceptor/context/GetSuffixOperationContext.java Sun Apr 15 12:08:12 2007
@@ -28,22 +28,22 @@
  * @author <a href="mailto:dev@directory.apache.org">Apache Directory Project</a>
  * @version $Rev$, $Date$
  */
-public class GetSuffixServiceContext  extends AbstractServiceContext
+public class GetSuffixOperationContext  extends AbstractOperationContext
 {
     /**
      * Creates a new instance of GetSuffixServiceContext.
      */
-    public GetSuffixServiceContext()
+    public GetSuffixOperationContext()
     {
         super();
     }
     
     /**
      * Creates a new instance of GetSuffixServiceContext.
      *
      * @param dn The DN to get the suffix from
      */
-    public GetSuffixServiceContext( LdapDN dn )
+    public GetSuffixOperationContext( LdapDN dn )
     {
         super( dn );
     }
@@ -53,6 +53,6 @@
      */
     public String toString()
     {
-        return "GetSuffixServiceContext with DN '" + getDn().getUpName() + "'";
+        return "GetSuffixOperationContext with DN '" + getDn().getUpName() + "'";
     }
 }
@@ -28,22 +28,22 @@
 {
     /**
-     * Creates a new instance of GetSuffixServiceContext.
+     * Creates a new instance of GetSuffixOperationContext.
      */
@@ -28,22 +28,22 @@
     
     /**
-     * Creates a new instance of GetSuffixServiceContext.
+     * Creates a new instance of GetSuffixOperationContext.
      *
      * @param dn The DN to get the suffix from

Added: directory/apacheds/trunk/core/src/main/java/org/apache/directory/server/core/interceptor/context/ListOperationContext.java
URL: http://svn.apache.org/viewvc/directory/apacheds/trunk/core/src/main/java/org/apache/directory/server/core/interceptor/context/ListOperationContext.java?view=auto&rev=529046
==============================================================================
--- directory/apacheds/trunk/core/src/main/java/org/apache/directory/server/core/interceptor/context/UnbindServiceContext.java (original)
+++ directory/apacheds/trunk/core/src/main/java/org/apache/directory/server/core/interceptor/context/UnbindOperationContext.java Sun Apr 15 12:08:12 2007
@@ -28,22 +28,22 @@
  * @author <a href="mailto:dev@directory.apache.org">Apache Directory Project</a>
  * @version $Rev$, $Date$
  */
-public class UnbindServiceContext  extends AbstractServiceContext
+public class UnbindOperationContext  extends AbstractOperationContext
 {
     /**
      * Creates a new instance of UnbindServiceContext.
      */
-    public UnbindServiceContext()
+    public UnbindOperationContext()
     {
         super();
     }
     
     /**
      * Creates a new instance of UnbindServiceContext.
      *
      * @param unbindDn The principal DN to unbind
      */
-    public UnbindServiceContext( LdapDN unbindDn )
+    public UnbindOperationContext( LdapDN unbindDn )
     {
         super( unbindDn );
     }
@@ -28,22 +28,22 @@
 {
     /**
-     * Creates a new instance of UnbindServiceContext.
+     * Creates a new instance of UnbindOperationContext.
      */
@@ -28,22 +28,22 @@
     
     /**
-     * Creates a new instance of UnbindServiceContext.
+     * Creates a new instance of UnbindOperationContext.
      *
      * @param unbindDn The principal DN to unbind

Modified: directory/apacheds/trunk/core/src/main/java/org/apache/directory/server/core/jndi/AbstractContextFactory.java
URL: http://svn.apache.org/viewvc/directory/apacheds/trunk/core/src/main/java/org/apache/directory/server/core/jndi/AbstractContextFactory.java?view=diff&rev=529046&r1=529045&r2=529046
==============================================================================
--- directory/apacheds/trunk/core/src/main/java/org/apache/directory/server/core/partition/AbstractPartition.java (original)
+++ directory/apacheds/trunk/core/src/main/java/org/apache/directory/server/core/partition/AbstractPartition.java Sun Apr 15 12:08:12 2007
@@ -32,11 +32,11 @@
 
 import org.apache.directory.server.core.DirectoryServiceConfiguration;
 import org.apache.directory.server.core.configuration.PartitionConfiguration;
-import org.apache.directory.server.core.interceptor.context.LookupServiceContext;
-import org.apache.directory.server.core.interceptor.context.RenameServiceContext;
-import org.apache.directory.server.core.interceptor.context.ModifyServiceContext;
-import org.apache.directory.server.core.interceptor.context.MoveServiceContext;
-import org.apache.directory.server.core.interceptor.context.ServiceContext;
+import org.apache.directory.server.core.interceptor.context.LookupOperationContext;
+import org.apache.directory.server.core.interceptor.context.RenameOperationContext;
+import org.apache.directory.server.core.interceptor.context.ModifyOperationContext;
+import org.apache.directory.server.core.interceptor.context.MoveOperationContext;
+import org.apache.directory.server.core.interceptor.context.OperationContext;
 import org.apache.directory.shared.ldap.message.ModificationItemImpl;
 import org.apache.directory.shared.ldap.name.LdapDN;
 
@@ -190,15 +190,15 @@
 
 
     /**
      * This method calls {@link Partition#lookup(ServiceContext)} and return <tt>true</tt>
      * if it returns an entry by default.  Please override this method if
      * there is more effective way for your implementation.
      */
-    public boolean hasEntry( ServiceContext entryContext ) throws NamingException
+    public boolean hasEntry( OperationContext entryContext ) throws NamingException
     {
         try
         {
-            return lookup( new LookupServiceContext( entryContext.getDn() ) ) != null;
+            return lookup( new LookupOperationContext( entryContext.getDn() ) ) != null;
         }
         catch ( NameNotFoundException e )
         {
@@ -212,7 +212,7 @@
      * with null <tt>attributeIds</tt> by default.  Please override
      * this method if there is more effective way for your implementation.
      */
-    public Attributes lookup( ServiceContext lookupContext ) throws NamingException
+    public Attributes lookup( OperationContext lookupContext ) throws NamingException
     {
         return null;
         //return lookup( lookupContext );
@@ -226,9 +226,9 @@
      * Please override this method if there is more effactive way for your
      * implementation.
      */
-    public void modify( ServiceContext modifyContext ) throws NamingException
+    public void modify( OperationContext modifyContext ) throws NamingException
     {
-    	ModifyServiceContext ctx = (ModifyServiceContext)modifyContext;
+    	ModifyOperationContext ctx = (ModifyOperationContext)modifyContext;
     	int modOp = ctx.getModOp();
     	Attributes mods = ctx.getMods(); 
     	
@@ -247,8 +247,8 @@
 
 
     /**
      * This method calls {@link Partition#move(ServiceContext)} and
      * {@link Partition#rename(ServiceContext)} subsequently
      * by default.  Please override this method if there is more effactive
      * way for your implementation.
      */
@@ -256,8 +256,8 @@
     {
         LdapDN newName = ( LdapDN ) newParentName.clone();
         newName.add( newRdn );
-        replace( new MoveServiceContext( oldName, newParentName ) );
-        rename( new RenameServiceContext( newName, newRdn, deleteOldRn ) );
+        replace( new MoveOperationContext( oldName, newParentName ) );
+        rename( new RenameOperationContext( newName, newRdn, deleteOldRn ) );
     }
 
 
@@ -265,7 +265,7 @@
      * This method throws {@link OperationNotSupportedException} by default.
      * Please override this method to implement move operation.
      */
-    public void replace( ServiceContext replaceContext ) throws NamingException
+    public void replace( OperationContext replaceContext ) throws NamingException
     {
         throw new OperationNotSupportedException( "Moving an entry to other parent entry is not supported." );
     }
@@ -190,15 +190,15 @@
 
     /**
-     * This method calls {@link Partition#lookup(ServiceContext)} and return <tt>true</tt>
+     * This method calls {@link Partition#lookup(OperationContext)} and return <tt>true</tt>
      * if it returns an entry by default.  Please override this method if
      * there is more effective way for your implementation.
@@ -247,8 +247,8 @@
 
     /**
-     * This method calls {@link Partition#move(ServiceContext)} and
-     * {@link Partition#rename(ServiceContext)} subsequently
+     * This method calls {@link Partition#move(OperationContext)} and
+     * {@link Partition#rename(OperationContext)} subsequently
      * by default.  Please override this method if there is more effactive
      * way for your implementation.

Modified: directory/apacheds/trunk/core/src/main/java/org/apache/directory/server/core/partition/DefaultPartitionNexus.java
URL: http://svn.apache.org/viewvc/directory/apacheds/trunk/core/src/main/java/org/apache/directory/server/core/partition/DefaultPartitionNexus.java?view=diff&rev=529046&r1=529045&r2=529046
==============================================================================
--- directory/apacheds/trunk/core/src/main/java/org/apache/directory/server/core/partition/Partition.java (original)
+++ directory/apacheds/trunk/core/src/main/java/org/apache/directory/server/core/partition/Partition.java Sun Apr 15 12:08:12 2007
@@ -31,7 +31,7 @@
 
 import org.apache.directory.server.core.DirectoryServiceConfiguration;
 import org.apache.directory.server.core.configuration.PartitionConfiguration;
-import org.apache.directory.server.core.interceptor.context.ServiceContext;
+import org.apache.directory.server.core.interceptor.context.OperationContext;
 import org.apache.directory.shared.ldap.filter.ExprNode;
 import org.apache.directory.shared.ldap.message.ModificationItemImpl;
 import org.apache.directory.shared.ldap.name.LdapDN;
@@ -106,26 +106,26 @@
      * Deletes a leaf entry from this ContextPartition: non-leaf entries cannot be 
      * deleted until this operation has been applied to their children.
      *
      * @param deleteContext the context of the entry to
      * delete from this ContextPartition.
      * @throws NamingException if there are any problems
      */
-    void delete( ServiceContext deleteContext ) throws NamingException;
+    void delete( OperationContext opContext ) throws NamingException;
 
 
     /**
      * Adds an entry to this ContextPartition.
      *
      * @param addContext the context used  to add and entry to this ContextPartition
      * @throws NamingException if there are any problems
      */
-    void add( ServiceContext addContext ) throws NamingException;
+    void add( OperationContext opContext ) throws NamingException;
 
 
     /**
      * Modifies an entry by adding, removing or replacing a set of attributes.
      *
      * @param modifyContext The contetx containin the modification operation 
      * to perform on the entry which is one of constants specified by the 
      * DirContext interface:
      * <code>ADD_ATTRIBUTE, REMOVE_ATTRIBUTE, REPLACE_ATTRIBUTE</code>.
@@ -136,7 +136,7 @@
      * @see javax.naming.directory.DirContext#REMOVE_ATTRIBUTE
      * @see javax.naming.directory.DirContext#REPLACE_ATTRIBUTE
      */
-    void modify( ServiceContext modifyContext ) throws NamingException;
+    void modify( OperationContext opContext ) throws NamingException;
 
 
     /**
@@ -157,11 +157,11 @@
      * used to optimize operations rather than conducting a full search with 
      * retrieval.
      *
      * @param baseName the base distinguished/absolute name for the search/listing
      * @return a NamingEnumeration containing objects of type {@link SearchResult}
      * @throws NamingException if there are any problems
      */
-    NamingEnumeration list( LdapDN baseName ) throws NamingException;
+    NamingEnumeration list( OperationContext opContext ) throws NamingException;
 
 
     /**
@@ -197,16 +197,16 @@
      * @return an Attributes object representing the entry
      * @throws NamingException if there are any problems
      */
-    Attributes lookup( ServiceContext lookupContext ) throws NamingException;
+    Attributes lookup( OperationContext lookupContext ) throws NamingException;
 
     /**
      * Fast operation to check and see if a particular entry exists.
      *
      * @param ntry The entryContext used to pass informations
      * @return true if the entry exists, false if it does not
      * @throws NamingException if there are any problems
      */
-    boolean hasEntry( ServiceContext entryContext ) throws NamingException;
+    boolean hasEntry( OperationContext opContext ) throws NamingException;
 
     /**
      * Modifies an entry by changing its relative name. Optionally attributes
@@ -214,20 +214,20 @@
      * This makes sense only in certain namespaces like LDAP and will be ignored
      * if it is irrelavent.
      *
      * @param renameContext the modify DN context
      * @throws NamingException if there are any problems
      */
-    void rename( ServiceContext renameContext ) throws NamingException;
+    void rename( OperationContext opContext ) throws NamingException;
 
 
     /**
      * Transplants a child entry, to a position in the namespace under a new
      * parent entry.
      *
      * @param moveContext The context containing the DNs to move
      * @throws NamingException if there are any problems
      */
-    void move( ServiceContext moveContext ) throws NamingException;
+    void move( OperationContext opContext ) throws NamingException;
 
 
     /**
@@ -238,11 +238,11 @@
      * namespace this parameters is ignored.  An example of a namespace where
      * this parameter is significant is the LDAP namespace.
      *
      * @param moveAndRenameContext The context contain all the information about
      * the modifyDN operation
      * @throws NamingException if there are any problems
      */
-    void moveAndRename( ServiceContext moveAndRenameContext ) throws NamingException;
+    void moveAndRename( OperationContext opContext ) throws NamingException;
 
 
     /**
@@ -250,18 +250,18 @@
      * need not support this operation.  This operation is here to enable those
      * interested in implementing virtual directories with ApacheDS.
      * 
      * @param bindContext the bind context, containing all the needed informations to bind
      * @throws NamingException if something goes wrong
      */
-    void bind( ServiceContext bindContext ) throws NamingException;
+    void bind( OperationContext opContext ) throws NamingException;
 
     /**
      * Represents an unbind operation issued by an authenticated client.  Partitions
      * need not support this operation.  This operation is here to enable those
      * interested in implementing virtual directories with ApacheDS.
      * 
      * @param unbindContext the context used to unbind
      * @throws NamingException if something goes wrong
      */
-    void unbind( ServiceContext unbindContext ) throws NamingException;
+    void unbind( OperationContext opContext ) throws NamingException;
 }
@@ -106,26 +106,26 @@
      * deleted until this operation has been applied to their children.
      *
-     * @param deleteContext the context of the entry to
+     * @param opContext the context of the entry to
      * delete from this ContextPartition.
      * @throws NamingException if there are any problems
@@ -106,26 +106,26 @@
      * Adds an entry to this ContextPartition.
      *
-     * @param addContext the context used  to add and entry to this ContextPartition
+     * @param opContext the context used  to add and entry to this ContextPartition
      * @throws NamingException if there are any problems
      */
@@ -106,26 +106,26 @@
      * Modifies an entry by adding, removing or replacing a set of attributes.
      *
-     * @param modifyContext The contetx containin the modification operation 
+     * @param opContext The contetx containin the modification operation 
      * to perform on the entry which is one of constants specified by the 
      * DirContext interface:
@@ -157,11 +157,11 @@
      * retrieval.
      *
-     * @param baseName the base distinguished/absolute name for the search/listing
+     * @param opContext the context containing the distinguished/absolute name for the search/listing
      * @return a NamingEnumeration containing objects of type {@link SearchResult}
      * @throws NamingException if there are any problems
@@ -197,16 +197,16 @@
      * Fast operation to check and see if a particular entry exists.
      *
-     * @param ntry The entryContext used to pass informations
+     * @param opContext The context used to pass informations
      * @return true if the entry exists, false if it does not
      * @throws NamingException if there are any problems
@@ -214,20 +214,20 @@
      * if it is irrelavent.
      *
-     * @param renameContext the modify DN context
+     * @param opContext the modify DN context
      * @throws NamingException if there are any problems
      */
@@ -214,20 +214,20 @@
      * parent entry.
      *
-     * @param moveContext The context containing the DNs to move
+     * @param opContext The context containing the DNs to move
      * @throws NamingException if there are any problems
      */
@@ -238,11 +238,11 @@
      * this parameter is significant is the LDAP namespace.
      *
-     * @param moveAndRenameContext The context contain all the information about
+     * @param opContext The context contain all the information about
      * the modifyDN operation
      * @throws NamingException if there are any problems
@@ -250,18 +250,18 @@
      * interested in implementing virtual directories with ApacheDS.
      * 
-     * @param bindContext the bind context, containing all the needed informations to bind
+     * @param opContext the bind context, containing all the needed informations to bind
      * @throws NamingException if something goes wrong
      */
@@ -250,18 +250,18 @@
      * interested in implementing virtual directories with ApacheDS.
      * 
-     * @param unbindContext the context used to unbind
+     * @param opContext the context used to unbind
      * @throws NamingException if something goes wrong
      */